@@ -13,7 +13,7 @@ use Catalyst::Runtime '5.70';
 # Static::Simple: will serve static files from the application's root 
 #                 directory
 
-use Catalyst qw/-Debug/;
+use Catalyst;
 
 our $VERSION = '0.01';
 
@@ -28,8 +28,6 @@ our $VERSION = '0.01';
 
 __PACKAGE__->config( name => 'TestApp' );
 
-# Start the application
-__PACKAGE__->setup;
 
 
 =head1 NAME
